/**
 * @file EmoteCommand.java
 * 
 * Copyright (C) 2011 MUDCraft.org
 * All Rights Reserved.
 *
 * @author Geoffrey Davis
 *
 * $Id$
 */
package org.mudcraft.bukkit.socials.commands;

import org.bukkit.ChatColor;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.mudcraft.bukkit.socials.Socials;
import org.mudcraft.bukkit.socials.message.Message;

/**
 * The /emote command.
 * @author Geoffrey Davis
 */
public class EmoteCommand implements CommandExecutor {
    /**
     * Constructs a new {@link EmoteCommand} instance.
     * @param plugin the {@link Socials} object
     */
    public EmoteCommand(Socials plugin) {
        if (plugin == null) {
            // Throw an exception to indicate an error.
            throw new IllegalArgumentException("plugin is null");
        }
        this.plugin = plugin;
    }
    
    /**
     * Gets the {@link Socials} object.
     * @return the {@link Socials} object
     */
    public Socials getPlugin() {
        return plugin;
    }
    
    /**
     * Joins an array of strings.
     * @param array the {@link String}s to be joined together
     * @return the joined {@link String}
     */
    private static String join(String[] array) {
        // Create a string builder to contain the joined string.
        final StringBuilder stringBuilder = new StringBuilder();
        
        // Iterate over the contents of the array.
        for (String string: array) {
            // Skip empty strings.
            if (string != null && string.length() != 0) {
                if (stringBuilder.length() != 0) {
                    // Insert a space between each word.
                    stringBuilder.append(' ');
                }
                // Append the next word to the string.
                stringBuilder.append(string);
            }
        }
        return stringBuilder.toString();
    }
    
    /**
     * {@inheritDoc}
     */
    public boolean onCommand(
            CommandSender sender, Command command, String label,
            String[] split) {
        if (sender instanceof Player) {
            // Cast the command sender to a player.
            final Player player = (Player) sender;
            
            // Determine the input from the joined arguments.
            final String input = join(split).trim();
            
            // Make certain we have something to emote.
            if (input.length() != 0) {
                // Create a message object.
                final Message message = getPlugin().newMessage();
                
                // Populate the message context.
                message.getContext().setString("line", input);
                message.getContext().setString("name", player.getDisplayName());
                
                // Set up the format specifier.
                message.setFormatSpecifier("{name.string} {line.string}");
                
                // Set the color of the emote message.
                message.setChatColor(ChatColor.LIGHT_PURPLE);
                
                // Dispatch the message to any observers.
                message.send(player);
                return true;
            }
        }
        // Tell the command sender they're not allowed to do this.
        sender.sendMessage(ChatColor.RED + "You can't use this command anonymously!");
        return false;
    }

    /**
     * The {@link Socials} object.
     * @see {@literal #getPlugin()}
     */
    private final Socials plugin;
}
