/**
 * @file Gender.java
 * 
 * Copyright (C) 2011 MUDCraft.org
 * All Rights Reserved.
 *
 * @author Geoffrey Davis
 *
 * $Id$
 */
package org.mudcraft.bukkit.socials.user;

import com.avaje.ebean.annotation.EnumValue;

/**
 * The gender of a player.
 * @author Geoffrey Davis
 */
public enum Gender {
    /**
     * The player is female.
     */
    @EnumValue("FEMALE")
    FEMALE("her", "hers", "her", "she"),
    
    /**
     * The player is male.
     */
    @EnumValue("MALE")
    MALE("him", "his", "his", "he"),
    
    /**
     * The player is neither female or male.
     */
    @EnumValue("NONE")
    NONE("it", "its", "its", "it");
    
    /**
     * Constructs a new {@link Gender} instance.
     * @param objectivePronoun the objectivePronoun pronoun (him, her, it)
     * @param possessivePronoun the possessivePronoun pronoun (his, hers, its)
     * @param possessiveDeterminer the possessivePronoun determiner (his, her, its)
     * @param subjectivePronoun the subjectivePronoun pronoun (he, she, it)
     */
    private Gender(
            String objectivePronoun,
            String possessivePronoun,
            String possessiveDeterminer,
            String subjectivePronoun) {
        this.objectivePronoun = objectivePronoun;
        this.possessivePronoun = possessivePronoun;
        this.possessiveDeterminer = possessiveDeterminer;
        this.subjectivePronoun = subjectivePronoun;
    }
    /**
     * Gets the objective pronoun.
     * @return the gender's objective pronoun
     */
    public String getObjectivePronoun() {
        return objectivePronoun;
    }
    
    /**
     * Gets the possessive pronoun.
     * @return the gender's possessive pronoun
     */
    public String getPossessivePronoun() {
        return possessivePronoun;
    }
    
    /**
     * Gets the possessive determiner.
     * @return the gender's possessive determiner
     */
    public String getPossessiveDeterminer() {
        return possessiveDeterminer;
    }
    
    /**
     * Gets the reflexive pronoun.
     * @return the gender's reflexive pronoun
     */
    public String getReflexivePronoun() {
        return objectivePronoun + "self";
    }
    
    /**
     * Gets the subjective pronoun.
     * @return the gender's subjective pronoun
     */
    public String getSubjectivePronoun() {
        return subjectivePronoun;
    }
    
    /**
     * The objectivePronoun pronoun.
     * @see #getObjectivePronoun()
     */
    private final String objectivePronoun;
    
    /**
     * The possessivePronoun pronoun.
     * @see #getPossessivePronoun()
     */
    private final String possessivePronoun;
    
    /**
     * The possessivePronoun determiner.
     * @see #getPossessiveDeterminer()
     */
    private final String possessiveDeterminer;
    
    /**
     * The subjectivePronoun pronoun.
     * @see #getSubjectivePronoun()
     */
    private final String subjectivePronoun;
}
